@@ -1,3 +1,8 @@
+package main;
+
+use strict;
+use warnings;
+
 if ($^O eq 'MSWin32') {
     require Win32;
 }
@@ -56,6 +61,9 @@ else {
 	  $libc = load("cygwin1.dll");
 	  $libm = $libc;
 	}
+	elsif ($^O eq "freebsd") {
+	  $libc = load("libc.so.7");
+	}
     }
     if (!$libc) {
         die "Can't load -lc: ", DynaLoader::dl_error(), "\nGiving up.\n";
